==> styled-bootstrap-0.1.7-0.tgz: package/lib/Breadcrumbs/Breadcrumb.js <==
var _templateObject = _taggedTemplateLiteral(['\n  display: flex;\n  flex-wrap: wrap;\n  padding: ', '\n    ', ';\n  margin-bottom: ', ';\n  list-style: none;\n  background-color: ', ';\n  ', ';\n'], ['\n  display: flex;\n  flex-wrap: wrap;\n  padding: ', '\n    ', ';\n  margin-bottom: ', ';\n  list-style: none;\n  background-color: ', ';\n  ', ';\n']),
    _templateObject2 = _taggedTemplateLiteral(['\n  :not(:first-child)::before {\n    display: inline-block;\n    padding-right: ', ';\n    padding-left: ', ';\n    color: ', ';\n    content: ', ';\n  }\n\n  :not(:first-child)&:hover::before {\n    text-decoration: underline;\n  }\n  :not(:first-child)&:hover::before {\n    text-decoration: none;\n  }\n\n  ', ';\n'], ['\n  :not(:first-child)::before {\n    display: inline-block;\n    padding-right: ', ';\n    padding-left: ', ';\n    color: ', ';\n    content: ', ';\n  }\n\n  :not(:first-child)&:hover::before {\n    text-decoration: underline;\n  }\n  :not(:first-child)&:hover::before {\n    text-decoration: none;\n  }\n\n  ', ';\n']);

function _taggedTemplateLiteral(strings, raw) { return Object.freeze(Object.defineProperties(strings, { raw: { value: Object.freeze(raw) } })); }

import styled from 'styled-components';
import PropTypes from 'prop-types';
import themeProp from '../utils/src/theme';

import { borderRadius } from '../utils/src/border-radius';

import { breadcrumbPaddingY, breadcrumbPaddingX, breadcrumbItemPadding, breadcrumbMarginBottom, breadcrumbBg, breadcrumbDividerColor, breadcrumbActiveColor, breadcrumbDivider } from './default-theme';

var Breadcrumb = styled.ol(_templateObject, themeProp('breadcrumbPaddingY', breadcrumbPaddingY), themeProp('breadcrumbPaddingX', breadcrumbPaddingX), themeProp('breadcrumbMarginBottom', breadcrumbMarginBottom), themeProp('breadcrumbBg', breadcrumbBg), borderRadius(themeProp('bordeRadius', '.25rem')));

Breadcrumb.Item = styled.li.attrs({
  'aria-current': function ariaCurrent(props) {
    return props.active && 'page';
  }
})(_templateObject2, themeProp('breadcrumbItemPadding', breadcrumbItemPadding), themeProp('breadcrumbItemPadding', breadcrumbItemPadding), themeProp('breadcrumbDividerColor', breadcrumbDividerColor), themeProp('breadcrumbDivider', breadcrumbDivider), function (_ref) {
  var active = _ref.active;
  return active && 'color: ' + themeProp('readcrumbActiveColor', breadcrumbActiveColor) + ';';
});

Breadcrumb.defaultProps = {};

Breadcrumb.Item.defaultProps = {
  active: false
};

Breadcrumb.Item.Proptypes = {
  active: PropTypes.bool
};

export default Breadcrumb;

==> styled-bootstrap-0.1.9.tgz: package/lib/Breadcrumbs/Breadcrumb.js <==
var _templateObject = _taggedTemplateLiteral(['\n  display: flex;\n  flex-wrap: wrap;\n  padding: ', '\n    ', ';\n  margin-bottom: ', ';\n  list-style: none;\n  background-color: ', ';\n  ', ';\n'], ['\n  display: flex;\n  flex-wrap: wrap;\n  padding: ', '\n    ', ';\n  margin-bottom: ', ';\n  list-style: none;\n  background-color: ', ';\n  ', ';\n']),
    _templateObject2 = _taggedTemplateLiteral(['\n  :not(:first-child)::before {\n    display: inline-block;\n    padding-right: ', ';\n    padding-left: ', ';\n    color: ', ';\n    content: ', ';\n  }\n\n  :not(:first-child)&:hover::before {\n    text-decoration: underline;\n  }\n  :not(:first-child)&:hover::before {\n    text-decoration: none;\n  }\n\n  ', ';\n'], ['\n  :not(:first-child)::before {\n    display: inline-block;\n    padding-right: ', ';\n    padding-left: ', ';\n    color: ', ';\n    content: ', ';\n  }\n\n  :not(:first-child)&:hover::before {\n    text-decoration: underline;\n  }\n  :not(:first-child)&:hover::before {\n    text-decoration: none;\n  }\n\n  ', ';\n']);

function _taggedTemplateLiteral(strings, raw) { return Object.freeze(Object.defineProperties(strings, { raw: { value: Object.freeze(raw) } })); }

import styled from 'styled-components';
import PropTypes from 'prop-types';
import themeProp from '../utils/theme';

import { borderRadius } from '../utils/border-radius';

import { breadcrumbPaddingY, breadcrumbPaddingX, breadcrumbItemPadding, breadcrumbMarginBottom, breadcrumbBg, breadcrumbDividerColor, breadcrumbActiveColor, breadcrumbDivider } from './default-theme';

var Breadcrumb = styled.ol(_templateObject, themeProp('breadcrumbPaddingY', breadcrumbPaddingY), themeProp('breadcrumbPaddingX', breadcrumbPaddingX), themeProp('breadcrumbMarginBottom', breadcrumbMarginBottom), themeProp('breadcrumbBg', breadcrumbBg), borderRadius(themeProp('bordeRadius', '.25rem')));

Breadcrumb.Item = styled.li.attrs({
  'aria-current': function ariaCurrent(props) {
    return props.active && 'page';
  }
})(_templateObject2, themeProp('breadcrumbItemPadding', breadcrumbItemPadding), themeProp('breadcrumbItemPadding', breadcrumbItemPadding), themeProp('breadcrumbDividerColor', breadcrumbDividerColor), themeProp('breadcrumbDivider', breadcrumbDivider), function (_ref) {
  var active = _ref.active;
  return active && 'color: ' + themeProp('readcrumbActiveColor', breadcrumbActiveColor) + ';';
});

Breadcrumb.defaultProps = {};

Breadcrumb.Item.defaultProps = {
  active: false
};

Breadcrumb.Item.Proptypes = {
  active: PropTypes.bool
};

export default Breadcrumb;
